; Elektronischer Weihnachtsbaum mit ATtiny2313
; Nils Hintze 2009, 2011, 2015
; Takt: 1 MHz (Interner RC-Oszillator 8 MHz mit Vorteiler 8)
; Fuses: L=0x64 H=0xDF X=0xFF (Voreinstellung im Auslieferungszustand)

.include "tn2313def.inc"

; Register definieren
.def	temp = r16
.def	zero = r17

; Interrupt-Vektoren
.org 0
	rjmp	reset
.org OC1Aaddr
	rjmp	oc1a

; Initialisierung
reset:	clr	zero			; Nullregister lschen
	ldi	temp, RAMEND		; Stackpointer initialisieren
	out	SPL, temp		; 
	ldi	temp, 0xFF		; PB0..7 als Ausgang fr die LEDs
	out	DDRB, temp		; 
	out	PORTB, temp		; Alle LEDs aus
	ldi	temp, 0x7F		; PD0..6 als Ausgang fr die LEDs
	out	DDRD, temp		; 
	out	PORTD, temp		; Alle LEDs aus
	rcall	initzp			; Z-Pointer auf Anfang
	sei				; Interrupts global aktivieren
	ldi	temp, 1<<OCIE1A		; Timer 1 Output Compare A Match Interrupt aktivieren
	out	TIMSK, temp		; 
	ldi	temp, 0x08		; Compare-Wert fr Interrupt nach ca. 0,5 s
	out	OCR1AH, temp		; 
	out	OCR1AL, zero		; 
	ldi	temp, 1<<WGM12|1<<CS12	; Timer 1 CTC-Modus mit OCR1A und Vorteiler 256
	out	TCCR1B, temp		; 
loop:	rjmp	loop			; Endlosschleife

; Timer-Interrupt
oc1a:	lpm	temp, Z+		; Erstes Programm-Byte laden
	out	OCR1AH, temp		; Compare-Wert ausgeben
	out	OCR1AL, zero		; 
	lpm	temp, Z+		; Zweites Programm-Byte laden
	com	temp			; invertieren
	out	PORTB, temp		; und ausgeben
	lpm	temp, Z+		; Drittes Programm-Byte laden
	sbrc	temp, 7			; Wenn Ende-Bit gesetzt
	rcall	initzp			; dann Z-Pointer auf Anfang
	com	temp			; invertieren
	andi	temp, 0x7F		; LED-Bits filtern
	out	PORTD, temp		; und ausgeben
	reti				; Ende

; Z-Pointer zurcksetzen
initzp:	ldi	ZL, LOW(2*prgtab)	; Z-Pointer auf Anfang der Programmtabelle setzen
	ldi	ZH, HIGH(2*prgtab)	; 
	ret				; Ende

; Programm
prgtab:	.db 0x07, 0x07
	.db 0x70, 0x07
	.db 0x18, 0x1A
	.db 0x07, 0xE0
	.db 0x15, 0x07
	.db 0x00, 0x00
	.db 0x07, 0x07
	.db 0x70, 0x07
	.db 0x18, 0x1A
	.db 0x07, 0xE0
	.db 0x15, 0x07
	.db 0x00, 0x00
	.db 0x07, 0x07
	.db 0x70, 0x07
	.db 0x1F, 0x7A
	.db 0x98, 0xFF
	.db 0x7F, 0x98
	.db 0xFF, 0x7F
	.db 0x07, 0x00
	.db 0x00, 0x01
	.db 0x01, 0x00
	.db 0x01, 0x03
	.db 0x00, 0x01
	.db 0x07, 0x00
	.db 0x01, 0x0F
	.db 0x00, 0x01
	.db 0x1F, 0x00
	.db 0x01, 0x3F
	.db 0x00, 0x01
	.db 0x7F, 0x00
	.db 0x01, 0xFF
	.db 0x00, 0x01
	.db 0xFF, 0x01
	.db 0x01, 0xFF
	.db 0x03, 0x01
	.db 0xFF, 0x07
	.db 0x01, 0xFF
	.db 0x0F, 0x01
	.db 0xFF, 0x1F
	.db 0x01, 0xFF
	.db 0x3F, 0x0F
	.db 0xFF, 0x7F
	.db 0x01, 0xFE
	.db 0x7F, 0x01
	.db 0xFC, 0x7F
	.db 0x01, 0xF8
	.db 0x7F, 0x01
	.db 0xF0, 0x7F
	.db 0x01, 0xE0
	.db 0x7F, 0x01
	.db 0xC0, 0x7F
	.db 0x01, 0x80
	.db 0x7F, 0x01
	.db 0x00, 0x7F
	.db 0x01, 0x00
	.db 0x7E, 0x01
	.db 0x00, 0x7C
	.db 0x01, 0x00
	.db 0x78, 0x01
	.db 0x00, 0x70
	.db 0x01, 0x00
	.db 0x60, 0x01
	.db 0x00, 0x40
	.db 0x0F, 0x00
	.db 0x00, 0x01
	.db 0x01, 0x00
	.db 0x01, 0x03
	.db 0x00, 0x01
	.db 0x07, 0x00
	.db 0x01, 0x0F
	.db 0x00, 0x01
	.db 0x1F, 0x00
	.db 0x01, 0x3F
	.db 0x00, 0x01
	.db 0x7F, 0x00
	.db 0x01, 0xFF
	.db 0x00, 0x01
	.db 0xFF, 0x01
	.db 0x01, 0xFF
	.db 0x03, 0x01
	.db 0xFF, 0x07
	.db 0x01, 0xFF
	.db 0x0F, 0x01
	.db 0xFF, 0x1F
	.db 0x01, 0xFF
	.db 0x3F, 0x0F
	.db 0xFF, 0x7F
	.db 0x01, 0xFE
	.db 0x7F, 0x01
	.db 0xFC, 0x7F
	.db 0x01, 0xF8
	.db 0x7F, 0x01
	.db 0xF0, 0x7F
	.db 0x01, 0xE0
	.db 0x7F, 0x01
	.db 0xC0, 0x7F
	.db 0x01, 0x80
	.db 0x7F, 0x01
	.db 0x00, 0x7F
	.db 0x01, 0x00
	.db 0x7E, 0x01
	.db 0x00, 0x7C
	.db 0x01, 0x00
	.db 0x78, 0x01
	.db 0x00, 0x70
	.db 0x01, 0x00
	.db 0x60, 0x01
	.db 0x00, 0x40
	.db 0x0F, 0x00
	.db 0x00, 0x01
	.db 0x01, 0x00
	.db 0x01, 0x03
	.db 0x00, 0x01
	.db 0x07, 0x00
	.db 0x01, 0x0F
	.db 0x00, 0x01
	.db 0x1F, 0x00
	.db 0x01, 0x3F
	.db 0x00, 0x01
	.db 0x7F, 0x00
	.db 0x01, 0xFF
	.db 0x00, 0x01
	.db 0xFF, 0x01
	.db 0x01, 0xFF
	.db 0x03, 0x01
	.db 0xFF, 0x07
	.db 0x01, 0xFF
	.db 0x0F, 0x01
	.db 0xFF, 0x1F
	.db 0x01, 0xFF
	.db 0x3F, 0x0F
	.db 0xFF, 0x7F
	.db 0x01, 0xFE
	.db 0x7F, 0x01
	.db 0xFC, 0x7F
	.db 0x01, 0xF8
	.db 0x7F, 0x01
	.db 0xF0, 0x7F
	.db 0x01, 0xE0
	.db 0x7F, 0x01
	.db 0xC0, 0x7F
	.db 0x01, 0x80
	.db 0x7F, 0x01
	.db 0x00, 0x7F
	.db 0x01, 0x00
	.db 0x7E, 0x01
	.db 0x00, 0x7C
	.db 0x01, 0x00
	.db 0x78, 0x01
	.db 0x00, 0x70
	.db 0x01, 0x00
	.db 0x60, 0x01
	.db 0x00, 0x40
	.db 0x0F, 0x00
	.db 0x00, 0x01
	.db 0x01, 0x00
	.db 0x01, 0x03
	.db 0x00, 0x01
	.db 0x07, 0x00
	.db 0x01, 0x0F
	.db 0x00, 0x01
	.db 0x1F, 0x00
	.db 0x01, 0x3F
	.db 0x00, 0x01
	.db 0x7F, 0x00
	.db 0x01, 0xFF
	.db 0x00, 0x01
	.db 0xFF, 0x01
	.db 0x01, 0xFF
	.db 0x03, 0x01
	.db 0xFF, 0x07
	.db 0x01, 0xFF
	.db 0x0F, 0x01
	.db 0xFF, 0x1F
	.db 0x01, 0xFF
	.db 0x3F, 0x0F
	.db 0xFF, 0x7F
	.db 0x01, 0xFE
	.db 0x7F, 0x01
	.db 0xFC, 0x7F
	.db 0x01, 0xF8
	.db 0x7F, 0x01
	.db 0xF0, 0x7F
	.db 0x01, 0xE0
	.db 0x7F, 0x01
	.db 0xC0, 0x7F
	.db 0x01, 0x80
	.db 0x7F, 0x01
	.db 0x00, 0x7F
	.db 0x01, 0x00
	.db 0x7E, 0x01
	.db 0x00, 0x7C
	.db 0x01, 0x00
	.db 0x78, 0x01
	.db 0x00, 0x70
	.db 0x01, 0x00
	.db 0x60, 0x01
	.db 0x00, 0x40
	.db 0x0F, 0x00
	.db 0x00, 0x01
	.db 0x01, 0x00
	.db 0x01, 0x03
	.db 0x00, 0x01
	.db 0x07, 0x00
	.db 0x01, 0x0F
	.db 0x00, 0x01
	.db 0x1F, 0x00
	.db 0x01, 0x3F
	.db 0x00, 0x01
	.db 0x7F, 0x00
	.db 0x01, 0xFF
	.db 0x00, 0x01
	.db 0xFF, 0x01
	.db 0x01, 0xFF
	.db 0x03, 0x01
	.db 0xFF, 0x07
	.db 0x01, 0xFF
	.db 0x0F, 0x01
	.db 0xFF, 0x1F
	.db 0x01, 0xFF
	.db 0x3F, 0x0F
	.db 0xFF, 0x7F
	.db 0x01, 0xFE
	.db 0x7F, 0x01
	.db 0xFC, 0x7F
	.db 0x01, 0xF8
	.db 0x7F, 0x01
	.db 0xF0, 0x7F
	.db 0x01, 0xE0
	.db 0x7F, 0x01
	.db 0xC0, 0x7F
	.db 0x01, 0x80
	.db 0x7F, 0x01
	.db 0x00, 0x7F
	.db 0x01, 0x00
	.db 0x7E, 0x01
	.db 0x00, 0x7C
	.db 0x01, 0x00
	.db 0x78, 0x01
	.db 0x00, 0x70
	.db 0x01, 0x00
	.db 0x60, 0x01
	.db 0x00, 0x40
	.db 0x0F, 0x00
	.db 0x00, 0x07
	.db 0x00, 0x00
	.db 0x0F, 0x57
	.db 0x4F, 0x0F
	.db 0x42, 0x5C
	.db 0x0F, 0xC9
	.db 0x29, 0x0F
	.db 0x67, 0x6F
	.db 0x0F, 0x06
	.db 0x6B, 0x0F
	.db 0xE6, 0x42
	.db 0x0F, 0xC5
	.db 0x16, 0x0F
	.db 0xFA, 0x1A
	.db 0x0F, 0xCA
	.db 0x67, 0x0F
	.db 0x71, 0x05
	.db 0x0F, 0x81
	.db 0x05, 0x0F
	.db 0x8D, 0x54
	.db 0x0F, 0xA6
	.db 0x28, 0x0F
	.db 0x0C, 0x17
	.db 0x0F, 0x3B
	.db 0x22, 0x0F
	.db 0xFD, 0x55
	.db 0x0F, 0x01
	.db 0x79, 0x0F
	.db 0x3C, 0x56
	.db 0x0F, 0x43
	.db 0x0B, 0x0F
	.db 0xA4, 0x7F
	.db 0x0F, 0xD9
	.db 0x1E, 0x0F
	.db 0x37, 0x5E
	.db 0x0F, 0x9D
	.db 0x74, 0x0F
	.db 0xF7, 0x6A
	.db 0x0F, 0x06
	.db 0x0B, 0x0F
	.db 0x0D, 0x58
	.db 0x0F, 0xB6
	.db 0x7E, 0x0F
	.db 0xE2, 0x1A
	.db 0x0F, 0x9C
	.db 0x60, 0x0F
	.db 0x9D, 0x63
	.db 0x0F, 0xCF
	.db 0x63, 0x0F
	.db 0x9D, 0x31
	.db 0x0F, 0x8E
	.db 0x67, 0x0F
	.db 0x6D, 0x79
	.db 0x0F, 0x92
	.db 0x39, 0x0F
	.db 0xCF, 0x30
	.db 0x0F, 0x72
	.db 0x74, 0x0F
	.db 0x80, 0x51
	.db 0x0F, 0xCF
	.db 0x67, 0x07
	.db 0x00, 0x00
	.db 0x07, 0x40
	.db 0x00, 0x07
	.db 0x50, 0x00
	.db 0x07, 0x50
	.db 0x20, 0x07
	.db 0x50, 0x24
	.db 0x07, 0x58
	.db 0x24, 0x07
	.db 0xD8, 0x24
	.db 0x07, 0xD8
	.db 0x34, 0x07
	.db 0xD8, 0x36
	.db 0x08, 0xD8
	.db 0x37, 0x09
	.db 0xD8, 0x3F
	.db 0x09, 0xD8
	.db 0x2F, 0x0A
	.db 0xD8, 0x0F
	.db 0x0B, 0xD8
	.db 0x0D, 0x0C
	.db 0xD8, 0x2D
	.db 0x0C, 0xD8
	.db 0x25, 0x0D
	.db 0xDA, 0x25
	.db 0x0E, 0xDA
	.db 0x27, 0x0F
	.db 0xFA, 0x27
	.db 0x0F, 0xFA
	.db 0x37, 0x0F
	.db 0xDA, 0x37
	.db 0x0F, 0xDA
	.db 0x35, 0x0F
	.db 0x5A, 0x35
	.db 0x0F, 0xDA
	.db 0x35, 0x0F
	.db 0xDA, 0x3D
	.db 0x0F, 0xDA
	.db 0x7D, 0x0F
	.db 0xDA, 0x79
	.db 0x0F, 0xDE
	.db 0x79, 0x0F
	.db 0xCE, 0x79
	.db 0x0F, 0x4E
	.db 0x79, 0x0F
	.db 0x4E, 0x7B
	.db 0x0F, 0x4E
	.db 0x7F, 0x0F
	.db 0x4A, 0x7F
	.db 0x0F, 0x5A
	.db 0x7F, 0x0F
	.db 0x5A, 0x7B
	.db 0x0F, 0x4A
	.db 0x7B, 0x0F
	.db 0x4E, 0x7B
	.db 0x0F, 0x4A
	.db 0x7B, 0x0F
	.db 0x4A, 0x3B
	.db 0x0F, 0x4B
	.db 0x3B, 0x0F
	.db 0x49, 0x3B
	.db 0x0F, 0xC9
	.db 0x3B, 0x0F
	.db 0xC9, 0x39
	.db 0x0F, 0xC8
	.db 0x39, 0x0F
	.db 0xC8, 0x38
	.db 0x0F, 0xC8
	.db 0x3A, 0x0F
	.db 0xCC, 0x3A
	.db 0x0F, 0xCC
	.db 0x3B, 0x0F
	.db 0xDC, 0x3B
	.db 0x0F, 0xD4
	.db 0x3B, 0x0F
	.db 0xD4, 0x2B
	.db 0x0F, 0x54
	.db 0x2B, 0x0F
	.db 0x44, 0x2B
	.db 0x0F, 0x44
	.db 0x3B, 0x0F
	.db 0x40, 0x3B
	.db 0x0F, 0x40
	.db 0x39, 0x0F
	.db 0x40, 0x3B
	.db 0x0F, 0x40
	.db 0x1B, 0x0F
	.db 0x48, 0x1B
	.db 0x0F, 0x48
	.db 0x13, 0x0F
	.db 0x48, 0x12
	.db 0x0F, 0x4C
	.db 0x12, 0x0F
	.db 0x4D, 0x12
	.db 0x0F, 0x4D
	.db 0x10, 0x0F
	.db 0x4D, 0x50
	.db 0x0F, 0x4D
	.db 0x52, 0x0F
	.db 0x4D, 0x12
	.db 0x0F, 0xCD
	.db 0x12, 0x0F
	.db 0xDD, 0x12
	.db 0x0F, 0xDD
	.db 0x1A, 0x0F
	.db 0xD9, 0x1A
	.db 0x0F, 0xD9
	.db 0x1E, 0x0F
	.db 0xF9, 0x1E
	.db 0x0F, 0xFD
	.db 0x1E, 0x0F
	.db 0xBD, 0x1E
	.db 0x0F, 0xBD
	.db 0x5E, 0x0F
	.db 0xB9, 0x5E
	.db 0x0F, 0xB8
	.db 0x5E, 0x0F
	.db 0xB8, 0x5A
	.db 0x0F, 0xB9
	.db 0x5A, 0x0F
	.db 0xB9, 0x58
	.db 0x0F, 0x39
	.db 0x58, 0x0F
	.db 0x3B, 0x58
	.db 0x0F, 0x7B
	.db 0x58, 0x0F
	.db 0x5B, 0x58
	.db 0x0F, 0x5F
	.db 0x58, 0x0F
	.db 0x5D, 0x58
	.db 0x0F, 0x5D
	.db 0x48, 0x0F
	.db 0x5D, 0x4A
	.db 0x0F, 0x5D
	.db 0x4E, 0x0F
	.db 0x5D, 0x6E
	.db 0x0F, 0x5F
	.db 0x6E, 0x0F
	.db 0x5B, 0x6E
	.db 0x0F, 0x5B
	.db 0x66, 0x0F
	.db 0x59, 0x66
	.db 0x0F, 0x59
	.db 0x62, 0x0F
	.db 0x59, 0x66
	.db 0x0F, 0x59
	.db 0x46, 0x0F
	.db 0x59, 0x06
	.db 0x0F, 0x19
	.db 0x06, 0x0F
	.db 0x1D, 0x06
	.db 0x0F, 0x1F
	.db 0x06, 0x0F
	.db 0x1F, 0x02
	.db 0x0F, 0x17
	.db 0x02, 0x0F
	.db 0x17, 0x00
	.db 0x0F, 0x17
	.db 0x02, 0x0F
	.db 0x13, 0x02
	.db 0x0F, 0x53
	.db 0x02, 0x0F
	.db 0x57, 0x02
	.db 0x0F, 0x57
	.db 0x00, 0x0F
	.db 0x57, 0x20
	.db 0x0F, 0x77
	.db 0x20, 0x0F
	.db 0x77, 0x22
	.db 0x0F, 0x76
	.db 0x22, 0x0F
	.db 0x66, 0x22
	.db 0x0F, 0x64
	.db 0x22, 0x0F
	.db 0x64, 0x23
	.db 0x0F, 0x64
	.db 0x33, 0x0F
	.db 0x66, 0x33
	.db 0x0F, 0x66
	.db 0x31, 0x0F
	.db 0x66, 0x21
	.db 0x0F, 0x66
	.db 0x20, 0x0F
	.db 0xE6, 0x20
	.db 0x0F, 0xE6
	.db 0x21, 0x0F
	.db 0xE7, 0x21
	.db 0x0F, 0xE7
	.db 0x23, 0x0F
	.db 0xE7, 0x33
	.db 0x0F, 0xE7
	.db 0x73, 0x0F
	.db 0xEF, 0x73
	.db 0x0F, 0xEF
	.db 0x7B, 0x0F
	.db 0xEF, 0x3B
	.db 0x0F, 0xEF
	.db 0x2B, 0x0F
	.db 0xEF, 0x3B
	.db 0x0F, 0xEF
	.db 0x39, 0x0F
	.db 0xCF, 0x39
	.db 0x0F, 0x8F
	.db 0x39, 0x0F
	.db 0x8F, 0x79
	.db 0x0F, 0x8F
	.db 0x39, 0x0F
	.db 0x8B, 0x39
	.db 0x0F, 0x8B
	.db 0x31, 0x0F
	.db 0x8B, 0x11
	.db 0x0F, 0x8B
	.db 0x15, 0x0F
	.db 0x89, 0x15
	.db 0x0F, 0x09
	.db 0x15, 0x0F
	.db 0x09, 0x05
	.db 0x0F, 0x09
	.db 0x25, 0x0F
	.db 0x09, 0x21
	.db 0x0F, 0x09
	.db 0x01, 0x0F
	.db 0x19, 0x01
	.db 0x0F, 0x19
	.db 0x21, 0x0F
	.db 0x19, 0x25
	.db 0x0F, 0x09
	.db 0x25, 0x0F
	.db 0x09, 0x27
	.db 0x0F, 0x08
	.db 0x27, 0x0F
	.db 0x88, 0x27
	.db 0x0F, 0x88
	.db 0x26, 0x0F
	.db 0x08, 0x26
	.db 0x0F, 0x28
	.db 0x26, 0x0F
	.db 0x28, 0x06
	.db 0x0F, 0x08
	.db 0x06, 0x0F
	.db 0x08, 0x16
	.db 0x0F, 0x08
	.db 0x06, 0x0F
	.db 0x08, 0x46
	.db 0x0F, 0x00
	.db 0x46, 0x0F
	.db 0x08, 0x46
	.db 0x0F, 0x18
	.db 0x46, 0x0F
	.db 0x18, 0x42
	.db 0x0F, 0x10
	.db 0x42, 0x0F
	.db 0x50, 0x42
	.db 0x0F, 0x52
	.db 0x42, 0x0F
	.db 0x52, 0x4A
	.db 0x0F, 0x52
	.db 0x48, 0x0F
	.db 0x56, 0x48
	.db 0x0F, 0x54
	.db 0x48, 0x0F
	.db 0x5C, 0x48
	.db 0x0F, 0x5C
	.db 0x40, 0x0F
	.db 0x5E, 0x40
	.db 0x0F, 0xDE
	.db 0x40, 0x0F
	.db 0xDE, 0x41
	.db 0x0F, 0x9E
	.db 0x41, 0x0F
	.db 0x9A, 0x41
	.db 0x0F, 0x9A
	.db 0x49, 0x0F
	.db 0x9A, 0x09
	.db 0x0F, 0x8A
	.db 0x09, 0x0F
	.db 0xAA, 0x09
	.db 0x0F, 0xA2
	.db 0x09, 0x0F
	.db 0xA2, 0x49
	.db 0x0F, 0xE2
	.db 0x49, 0x0F
	.db 0xE6, 0x49
	.db 0x0F, 0xF6
	.db 0x49, 0x0F
	.db 0xE6, 0x49
	.db 0x0F, 0xE2
	.db 0x49, 0x0F
	.db 0xE0, 0x49
	.db 0x0F, 0xE4
	.db 0x49, 0x0F
	.db 0xE4, 0x69
	.db 0x0F, 0xF4
	.db 0x69, 0x0F
	.db 0xF4, 0x6B
	.db 0x0F, 0xF4
	.db 0x7B, 0x0F
	.db 0xE4, 0x7B
	.db 0x0F, 0xE4
	.db 0x7A, 0x0F
	.db 0xE4, 0x78
	.db 0x0F, 0xE6
	.db 0x78, 0x0F
	.db 0xC6, 0x78
	.db 0x0F, 0x86
	.db 0x78, 0x0F
	.db 0x86, 0x7A
	.db 0x0F, 0x96
	.db 0x7A, 0x0F
	.db 0x92, 0x7A
	.db 0x0F, 0x92
	.db 0x5A, 0x0F
	.db 0x92, 0x4A
	.db 0x07, 0x00
	.db 0x00, 0x07
	.db 0x01, 0x00
	.db 0x07, 0x05
	.db 0x00, 0x07
	.db 0x15, 0x00
	.db 0x07, 0x55
	.db 0x00, 0x07
	.db 0x55, 0x01
	.db 0x07, 0x55
	.db 0x05, 0x07
	.db 0x55, 0x15
	.db 0x07, 0x55
	.db 0x55, 0x07
	.db 0x54, 0x55
	.db 0x07, 0x50
	.db 0x55, 0x07
	.db 0x40, 0x55
	.db 0x07, 0x00
	.db 0x55, 0x07
	.db 0x00, 0x54
	.db 0x07, 0x00
	.db 0x50, 0x07
	.db 0x00, 0x40
	.db 0x07, 0x00
	.db 0x00, 0x07
	.db 0x00, 0x20
	.db 0x07, 0x00
	.db 0x28, 0x07
	.db 0x00, 0x2A
	.db 0x07, 0x80
	.db 0x2A, 0x07
	.db 0xA0, 0x2A
	.db 0x07, 0xA8
	.db 0x2A, 0x07
	.db 0xAA, 0x2A
	.db 0x07, 0xAA
	.db 0x0A, 0x07
	.db 0xAA, 0x02
	.db 0x07, 0xAA
	.db 0x00, 0x07
	.db 0x2A, 0x00
	.db 0x07, 0x0A
	.db 0x00, 0x07
	.db 0x02, 0x00
	.db 0x07, 0x00
	.db 0x00, 0x16
	.db 0x01, 0x00
	.db 0x16, 0x01
	.db 0x04, 0x16
	.db 0x01, 0x24
	.db 0x16, 0x21
	.db 0x24, 0x16
	.db 0x21, 0x34
	.db 0x16, 0x23
	.db 0x34, 0x16
	.db 0x33, 0x34
	.db 0x16, 0x37
	.db 0x34, 0x16
	.db 0x3F, 0x3C
	.db 0x16, 0x3F
	.db 0x74, 0x16
	.db 0x2F, 0x54
	.db 0x16, 0xAF
	.db 0x50, 0x16
	.db 0xAB, 0x54
	.db 0x16, 0x2B
	.db 0x55, 0x16
	.db 0x2A, 0x5D
	.db 0x16, 0x02
	.db 0x5D, 0x16
	.db 0x02, 0x58
	.db 0x16, 0x02
	.db 0x68, 0x16
	.db 0x02, 0x6D
	.db 0x16, 0x22
	.db 0x6F, 0x16
	.db 0x6A, 0x6F
	.db 0x16, 0x62
	.db 0x6D, 0x16
	.db 0x42, 0x65
	.db 0x16, 0x42
	.db 0x69, 0x16
	.db 0x62, 0x79
	.db 0x16, 0x52
	.db 0x79, 0x16
	.db 0xD0, 0x79
	.db 0x16, 0xD8
	.db 0x78, 0x16
	.db 0x98, 0x70
	.db 0x16, 0xB8
	.db 0x71, 0x16
	.db 0xF8, 0x79
	.db 0x16, 0xFC
	.db 0x7B, 0x16
	.db 0xE4, 0x7B
	.db 0x16, 0xE4
	.db 0x7D, 0x16
	.db 0xC4, 0x79
	.db 0x16, 0xC0
	.db 0x7D, 0x16
	.db 0xE4, 0x7D
	.db 0x16, 0xE4
	.db 0x6C, 0x16
	.db 0xEC, 0x68
	.db 0x16, 0xFE
	.db 0x68, 0x16
	.db 0xFE, 0x2C
	.db 0x16, 0xEA
	.db 0x2C, 0x16
	.db 0x8A, 0x2C
	.db 0x16, 0x82
	.db 0x0C, 0x16
	.db 0xAA, 0x0C
	.db 0x16, 0xAA
	.db 0x05, 0x16
	.db 0xA8, 0x25
	.db 0x16, 0xBA
	.db 0x25, 0x16
	.db 0x38, 0x25
	.db 0x16, 0x28
	.db 0x05, 0x16
	.db 0x78, 0x05
	.db 0x16, 0x5C
	.db 0x05, 0x16
	.db 0x1C, 0x15
	.db 0x16, 0x9D
	.db 0x15, 0x16
	.db 0x9D, 0x34
	.db 0x16, 0x9D
	.db 0x70, 0x16
	.db 0x1D, 0x71
	.db 0x16, 0x0D
	.db 0x70, 0x16
	.db 0x0D, 0x61
	.db 0x16, 0x9D
	.db 0x61, 0x16
	.db 0x1D, 0x63
	.db 0x16, 0x1D
	.db 0x42, 0x16
	.db 0x1D, 0x53
	.db 0x16, 0x3D
	.db 0x51, 0x16
	.db 0x34, 0x51
	.db 0x16, 0x74
	.db 0x71, 0x16
	.db 0x75, 0x75
	.db 0x16, 0x77
	.db 0x35, 0x16
	.db 0x7B, 0x35
	.db 0x16, 0x7B
	.db 0x36, 0x16
	.db 0x6B, 0x76
	.db 0x16, 0x2F
	.db 0x76, 0x16
	.db 0xAF, 0x56
	.db 0x16, 0x2F
	.db 0x54, 0x16
	.db 0xAD, 0x54
	.db 0x16, 0xA7
	.db 0x54, 0x16
	.db 0xA7, 0x34
	.db 0x16, 0xA3
	.db 0x30, 0x16
	.db 0xE3, 0x32
	.db 0x16, 0xE7
	.db 0x33, 0x16
	.db 0xE2, 0x33
	.db 0x16, 0x62
	.db 0x31, 0x16
	.db 0x63, 0x35
	.db 0x16, 0x6B
	.db 0x25, 0x16
	.db 0x7B, 0x2D
	.db 0x16, 0x7B
	.db 0x1D, 0x16
	.db 0xFB, 0x15
	.db 0x16, 0xF3
	.db 0x1D, 0x16
	.db 0xF2, 0x19
	.db 0x16, 0xF2
	.db 0x79, 0x16
	.db 0xF0, 0x7D
	.db 0x16, 0xF0
	.db 0x39, 0x16
	.db 0x72, 0x39
	.db 0x16, 0x6A
	.db 0x39, 0x16
	.db 0x68, 0x79
	.db 0x16, 0xEC
	.db 0x79, 0x16
	.db 0xEA, 0x79
	.db 0x16, 0xEA
	.db 0x73, 0x16
	.db 0xEA, 0x3B
	.db 0x16, 0xFA
	.db 0x33, 0x16
	.db 0x78, 0x33
	.db 0x16, 0x68
	.db 0x23, 0x16
	.db 0x6A, 0x03
	.db 0x16, 0x68
	.db 0x02, 0x16
	.db 0x78, 0x03
	.db 0x16, 0x7E
	.db 0x03, 0x16
	.db 0x5F, 0x03
	.db 0x16, 0x5D
	.db 0x01, 0x16
	.db 0xDD, 0x11
	.db 0x16, 0xDD
	.db 0x09, 0x16
	.db 0xDD, 0x69
	.db 0x16, 0xDC
	.db 0x6B, 0x16
	.db 0x9C, 0x6A
	.db 0x16, 0xBE
	.db 0x6A, 0x16
	.db 0xB6, 0x2A
	.db 0x16, 0x36
	.db 0x22, 0x16
	.db 0x76, 0x62
	.db 0x16, 0x7C
	.db 0x62, 0x16
	.db 0x7C, 0x6B
	.db 0x16, 0x6C
	.db 0x7B, 0x16
	.db 0x65, 0x7B
	.db 0x16, 0x6D
	.db 0x7A, 0x16
	.db 0xED, 0x72
	.db 0x16, 0x6D
	.db 0x73, 0x16
	.db 0x7D, 0x63
	.db 0x16, 0x7D
	.db 0x4B, 0x16
	.db 0x7D, 0x69
	.db 0x16, 0x7D
	.db 0x2D, 0x16
	.db 0x75, 0x2F
	.db 0x16, 0x71
	.db 0x3F, 0x16
	.db 0x51, 0x3D
	.db 0x16, 0x50
	.db 0x3F, 0x16
	.db 0x40, 0x37
	.db 0x16, 0x42
	.db 0x36, 0x16
	.db 0x43, 0x16
	.db 0x16, 0xC3
	.db 0x56, 0x16
	.db 0xC1, 0x57
	.db 0x16, 0x43
	.db 0x57, 0x16
	.db 0x47, 0x55
	.db 0x16, 0x4B
	.db 0x55, 0x16
	.db 0x4B, 0x65
	.db 0x16, 0x4B
	.db 0x69, 0x16
	.db 0x4B, 0x4B
	.db 0x16, 0xCF
	.db 0x4B, 0x16
	.db 0xDF, 0x0B
	.db 0x16, 0xFF
	.db 0x0A, 0x16
	.db 0xF7, 0x02
	.db 0x16, 0xFF
	.db 0x42, 0x16
	.db 0xBE, 0x42
	.db 0x16, 0xAE
	.db 0x02, 0x16
	.db 0x8E, 0x00
	.db 0x16, 0x8E
	.db 0x44, 0x16
	.db 0x9E, 0x45
	.db 0x16, 0x97
	.db 0x45, 0x16
	.db 0xD7, 0x4D
	.db 0x16, 0x97
	.db 0x5D, 0x16
	.db 0xB7, 0x7D
	.db 0x16, 0xB5
	.db 0x7C, 0x16
	.db 0xB5, 0x34
	.db 0x16, 0x35
	.db 0x30, 0x16
	.db 0x34, 0x31
	.db 0x16, 0xB4
	.db 0x30, 0x16
	.db 0xBC, 0x32
	.db 0x16, 0xBC
	.db 0x02, 0x16
	.db 0xBC, 0x62
	.db 0x16, 0xBC
	.db 0x6E, 0x16
	.db 0xBD, 0x66
	.db 0x16, 0x9D
	.db 0x62, 0x16
	.db 0xBF, 0x62
	.db 0x16, 0xBF
	.db 0x76, 0x16
	.db 0x9B, 0x76
	.db 0x16, 0x93
	.db 0x77, 0x16
	.db 0x91, 0x57
	.db 0x16, 0x99
	.db 0x56, 0x16
	.db 0x9B, 0x76
	.db 0x16, 0x99
	.db 0x36, 0x16
	.db 0xD9, 0x34
	.db 0x16, 0xC9
	.db 0x74, 0x16
	.db 0x59, 0x74
	.db 0x16, 0x5B
	.db 0x75, 0x16
	.db 0x58, 0x75
	.db 0x16, 0x98
	.db 0x75, 0x16
	.db 0x38, 0x75
	.db 0x16, 0x78
	.db 0x77, 0x16
	.db 0x7B, 0x77
	.db 0x16, 0x79
	.db 0x75, 0x16
	.db 0x7D, 0x74
	.db 0x16, 0x7D
	.db 0x24, 0x16
	.db 0x4D, 0x24
	.db 0x16, 0x0D
	.db 0x34, 0x16
	.db 0x09, 0x24
	.db 0x16, 0x08
	.db 0x26, 0x16
	.db 0x10, 0x26
	.db 0x16, 0x10
	.db 0x16, 0x16
	.db 0x14, 0x17
	.db 0x16, 0x10
	.db 0x07, 0x16
	.db 0x10, 0x25
	.db 0x16, 0x18
	.db 0x65, 0x16
	.db 0x38, 0x25
	.db 0x16, 0x38
	.db 0x04, 0x16
	.db 0x3C, 0x06
	.db 0x16, 0xBC
	.db 0x0E, 0x16
	.db 0x9E, 0x0E
	.db 0x16, 0x0E
	.db 0x0E, 0x16
	.db 0x2E, 0x4E
	.db 0x16, 0x2C
	.db 0x6E, 0x16
	.db 0x2D, 0x66
	.db 0x16, 0x2D
	.db 0x7E, 0x07
	.db 0x00, 0x80
